@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.24 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.26 2009/05/14 02:29:21 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -124,6 +124,10 @@ void GuiStat::newWin()
 		print_msg( FLG_MSG_ERR, "gtk_window_new()" );
 		return;
 	}
+	g_object_set( GTK_WINDOW( mStatWin ),
+			"allow-shrink", FALSE,
+			"allow-grow", FALSE,
+			NULL );
 	gtk_window_set_title( GTK_WINDOW( mStatWin ),
 			"Stat" );
 
@@ -149,6 +153,10 @@ void GuiStat::newWin()
 	// ľܥåκ
 
 	vBox = gtk_vbox_new( FALSE, 0 );
+	if( vBox == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_vbox_new()" );
+		return;
+	}
 	gtk_container_add( GTK_CONTAINER( mStatWin ), vBox );
 	gtk_widget_show( vBox );
 
@@ -157,6 +165,31 @@ void GuiStat::newWin()
 	party_t *pty = get_party();
 	for( long i = 0; i < MBR_MAX_N; i++ )
 		newWinMbr( pty->mbr[i], vBox );
+
+	// ¾ξ
+
+	vBoxMisc = gtk_vbox_new( FALSE, 0 );
+	if( vBoxMisc == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_vbox_new()" );
+		return;
+	}
+	gtk_box_pack_start( GTK_BOX( vBox ),
+			vBoxMisc, FALSE, FALSE, 0 );
+	gtk_widget_show( vBoxMisc );
+
+	// ؤ
+
+	labelDunLev = gtk_label_new( "Floor : 9999" );
+	gtk_box_pack_start( GTK_BOX( vBoxMisc ),
+			labelDunLev, FALSE, FALSE, 0 );
+	gtk_widget_show( labelDunLev );
+
+	// դ
+
+	labelTime = gtk_label_new( "12::00::" );
+	gtk_box_pack_start( GTK_BOX( vBoxMisc ),
+			labelTime, FALSE, FALSE, 0 );
+	gtk_widget_show( labelTime );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -186,8 +219,6 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 	// ġ롦С
 
-#if 1
-//@@@
 	handleBox[n] = gtk_handle_box_new();
 	gtk_box_pack_start( GTK_BOX( vBox ), handleBox[n], FALSE, FALSE, 0 );
 	gtk_widget_show( handleBox[n] );
@@ -204,20 +235,6 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 	vBox2[n] = gtk_vbox_new( FALSE, 0 );
 	gtk_container_add( GTK_CONTAINER( toolBar[n] ), vBox2[n] );
 	gtk_widget_show( vBox2[n] );
-#elif 0
-//@@@
-	handleBox[n] = gtk_handle_box_new();
-	gtk_box_pack_start( GTK_BOX( vBox ), handleBox[n], FALSE, FALSE, 0 );
-	gtk_widget_show( handleBox[n] );
-
-	vBox2[n] = gtk_vbox_new( FALSE, 0 );
-	gtk_container_add( GTK_CONTAINER( handleBox[n] ), vBox2[n] );
-	gtk_widget_show( vBox2[n] );
-#else
-	vBox2[n] = gtk_vbox_new( FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( vBox ), vBox2[n], FALSE, FALSE, 0 );
-	gtk_widget_show( vBox2[n] );
-#endif
 
 	// ơܥκ
 
@@ -351,6 +368,11 @@ void GuiStat::destroy()
 		labelMp[i] = NULL;
 	}
 
+	gtk_widget_destroy( labelDunLev );
+	gtk_widget_destroy( labelTime );
+	labelDunLev = NULL;
+	labelTime = NULL;
+
 	gtk_widget_destroy( vBox );
 
 	mStatWin = NULL;
@@ -371,6 +393,7 @@ void GuiStat::redraw( bool flagAdj, bool flagExpose )
 {
 	for( long i = 0; i < MBR_MAX_N; i++ )
 		draw( i, flagExpose );
+	drawMisc();
 
 	gWinPos[WIN_KIND_STAT].get( WIN_KIND_STAT,
 			NULL, NULL, NULL, NULL );
@@ -378,10 +401,6 @@ void GuiStat::redraw( bool flagAdj, bool flagExpose )
 		gWinPos[WIN_KIND_STAT].draw( WIN_KIND_STAT );
 
 #ifdef D_GTK
-	g_object_set( GTK_WINDOW( mStatWin ),
-			"allow-shrink", FALSE,
-			"allow-grow", FALSE,
-			NULL );
 	gtk_widget_show( vBox );
 #endif // D_GTK
 
@@ -397,6 +416,7 @@ void GuiStat::redraw( bool flagAdj, bool flagExpose )
 ////////////////////////////////////////////////////////////////
 // ơɥγƥСɽ
 // long mbrN : Сֹ
+// bool flagExpose : ɥ¤ؤ٥Ȥ?
 ////////////////////////////////////////////////////////////////
 
 void GuiStat::draw( long n, bool flagExpose )
@@ -487,6 +507,54 @@ void GuiStat::draw( long n, bool flagExpose )
 		gWinPos[WIN_KIND_STAT].draw( WIN_KIND_STAT );
 }
 
+////////////////////////////////////////////////////////////////
+// ơɥΤ¾ξɽ
+////////////////////////////////////////////////////////////////
+
+void GuiStat::drawMisc()
+{
+	newWin();
+
+	long maxLen = 40;
+	static char sPreDunLev[40 + 1] = "";
+	static char sPreTime[40 + 1] = "";
+	const char *sDunLev = get_stat_dun_lev_str();
+	const char *sTime = get_stat_time_str();
+
+#ifdef D_GTK
+	if( strcmp( sDunLev, sPreDunLev ) != 0 ){
+		gtk_misc_set_alignment( GTK_MISC( labelDunLev ),
+				0.0, 0.5 );
+		gtk_label_set_text( GTK_LABEL( labelDunLev ),
+				(char *)sDunLev );
+
+		str_nz_cpy( sPreDunLev, sDunLev, maxLen );
+	}
+
+	if( strcmp( sTime, sPreTime ) != 0 ){
+		gtk_misc_set_alignment( GTK_MISC( labelTime ),
+				0.0, 0.5 );
+		gtk_label_set_text( GTK_LABEL( labelTime ),
+				(char *)sTime );
+
+		str_nz_cpy( sPreTime, sTime, maxLen );
+	}
+
+	gtk_widget_show( labelDunLev );
+	gtk_widget_show( labelTime );
+#endif // D_GTK
+
+#ifdef D_MFC
+	if( strcmp( sDunLev, sPreDunLev ) != 0 ){
+		mStatWin->m_LabelDunLev.SetWindowText( sDunLev );
+	}
+
+	if( strcmp( sTime, sPreTime ) != 0 ){
+		mStatWin->m_LabelTime.SetWindowText( sTime );
+	}
+#endif // D_MFC
+}
+
 ////////////////////////////////////////////////////////////////
 // ơɥ HP/MP ΥС
 // long n : Сֹ
