@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelMbrGraph.cpp,v 1.5 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: SelMbrGraph.cpp,v 1.7 2009/05/14 08:33:26 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -350,6 +350,11 @@ void SelMbrGraph::close()
 
 void SelMbrGraph::redraw()
 {
+#ifdef D_MFC
+	g_Dir3d.SetRefreshRequest( true );
+	gPcgDun.setFlgUpdateRequest( true );
+#endif // D_MFC
+
 	// 롦С
 	if( nPreMapX <= -1 ){
 		nPreMapX = gPcgDun.getScrollBarX();
@@ -367,7 +372,7 @@ void SelMbrGraph::redraw()
 			nBaseColorR, nBaseColorG, nBaseColorB );
 
 	drawAllChr();
-	gPcgDun.flush( 0, 0, MAP_MAX_X, MAP_MAX_Y );
+	flush();
 }
 
 ////////////////////////////////////////////////////////////////
@@ -378,6 +383,7 @@ void SelMbrGraph::draw()
 {
 #ifdef D_GTK
 	drawAllChr();
+	flush();
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -507,3 +513,19 @@ void SelMbrGraph::drawChr(
 	p->drawOffset( gPcgDun.getWBuf(),
 			xx, yy, ptnW, ptnH, 0, 0 );
 }
+
+////////////////////////////////////////////////////////////////
+// Υեå
+////////////////////////////////////////////////////////////////
+
+void SelMbrGraph::flush()
+{
+	long tileSizeX = gPcgDun.getTileSizeX( false );
+	long tileSizeY = gPcgDun.getTileSizeY( false );
+	long mapX = gPcgDun.getScrollBarX() / tileSizeX;
+	long mapY = gPcgDun.getScrollBarY() / tileSizeY;
+	long mapW = (gPcgDun.getScrollBarW() + tileSizeX) / tileSizeX;
+	long mapH = (gPcgDun.getScrollBarH() + tileSizeY) / tileSizeY;
+
+	gPcgDun.flush( mapX, mapY, mapW, mapH );
+}
