@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.cpp,v 1.14 2009/03/13 14:54:38 bowkenken Exp $
+* $Id: WinPos.cpp,v 1.17 2009/05/12 00:34:56 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -272,10 +272,10 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 #ifdef D_GTK
 	gtk_widget_show( GTK_WIDGET( pWin ) );
 
-	gdk_window_move( GTK_WIDGET( pWin )->window, x, y );
-
-	GTK_WIDGET( pWin )->allocation.width = w;
-	GTK_WIDGET( pWin )->allocation.height = h;
+	if( g_flg_set_win_pos ){
+		gdk_window_move( GTK_WIDGET( pWin )->window, x, y );
+		gdk_window_resize( GTK_WIDGET( pWin )->window, w, h );
+	}
 
 	gdk_window_raise( GTK_WIDGET( pWin )->window );
 #endif //D_GTK
@@ -288,12 +288,16 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 		w = rect.Width();
 		h = rect.Height();
 
-		if( (w > 0) && (h > 0) )
-			((CDialog *)pWin)->MoveWindow( x, y, w, h );
+		if( g_flg_set_win_pos ){
+			if( (w > 0) && (h > 0) )
+				((CDialog *)pWin)->MoveWindow( x, y, w, h );
+		}
 	} else {
 		((CWnd *)pWin)->ShowWindow( SW_SHOW );
-		if( (w > 0) && (h > 0) )
-			((CWnd *)pWin)->MoveWindow( x, y, w, h );
+		if( g_flg_set_win_pos ){
+			if( (w > 0) && (h > 0) )
+				((CWnd *)pWin)->MoveWindow( x, y, w, h );
+		}
 		((CWnd *)pWin)->BringWindowToTop();
 		((CWnd *)pWin)->UpdateWindow();
 	}
