@@ -25,27 +25,42 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.227 2009/03/10 10:33:45 bowkenken Exp $
+* $Id: party.c,v 1.228 2009/05/14 00:26:39 bowkenken Exp $
+***************************************************************/
+
+/***************************************************************
+* ѡƥ (ץ쥤䡼饯)
 ***************************************************************/
 
 #define	PARTY_C
 #include	"inc.h"
 
-/**/
+/***************************************************************/
 
+/* 1 ˤȱΥ˥ǤΥƥȤ򤹤 */
 #define	FLG_NICOTINE_TEST	0
 
-/**/
+/***************************************************************/
+
+/* Сνǡ */
 
 #define	DFLT_EXP	500
 #define	DFLT_GOLD	3000
+#define	DFLT_GRAPH_NAME	"default.bmp"
 
+/* 1 ֶ᤯ΥСõƱΥȽꤹȾ */
 #define	MBR_NEAR_R	4
 
+/* ͤˤʤޤǤΥ */
 #define	FRIEND_MAX_TURN	(6 * TURN_PER_HOUR)
 
+/* СꥹȤζǡ */
 #define	LS_MBR_NULL	LS_MBR_MAX_N
 
+/***************************************************************
+* ѡƥΥǡ
+***************************************************************/
+
 static mbr_t	*ls_mbr[LS_MBR_MAX_N + 1];
 static mbr_t	ls_mbr_buf[LS_MBR_MAX_N + 1];
 static party_t	party;
@@ -139,7 +154,7 @@ typedef struct {
 
 #include	"class-tab.h"
 
-/**/
+/***************************************************************/
 
 void	init_party( void )
 {
@@ -1360,7 +1375,7 @@ void	new_mbr(
 	mbr->work.sync_vfx_x = MAP_DEL_X;
 	mbr->work.sync_vfx_y = MAP_DEL_Y;
 
-	mbr->graph_name[0] = '\0';
+	str_nz_cpy( mbr->graph_name, DFLT_GRAPH_NAME, FILE_NAME_MAX_LEN );
 
 	set_chr_id( mbr, get_ls_mbr(), LS_MBR_MAX_N );
 
